==> openflowplugin-extension-nicira-0.8.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/flow/mod/spec/flow/mod/spec/flow/mod/output/to/port/_case/FlowModOutputToPort.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.flow.mod.output.to.port._case;
import java.lang.Integer;
import java.lang.Long;
import org.eclipse.jdt.annotation.Nullable;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.FlowModSpec;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.ChildOf;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * container flow-mod-output-to-port {
 *   leaf flow-mod-num-bits {
 *     type uint16;
 *   }
 *   leaf src-field {
 *     type uint32;
 *   }
 *   leaf src-ofs {
 *     type uint16;
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/flow-mod-spec/flow-mod-spec/flow-mod-output-to-port-case/flow-mod-output-to-port</i>
 *
 * <p>To create instances of this class use {@link FlowModOutputToPortBuilder}.
 * @see FlowModOutputToPortBuilder
 *
 */
public interface FlowModOutputToPort
    extends
    ChildOf<FlowModSpec>,
    Augmentable<FlowModOutputToPort>
{



    public static final QName QNAME = $YangModuleInfoImpl.qnameOf("flow-mod-output-to-port");

    /**
     * @return <code>java.lang.Integer</code> <code>flowModNumBits</code>, or <code>null</code> if not present
     */
    @Nullable Integer getFlowModNumBits();
    
    /**
     * @return <code>java.lang.Long</code> <code>srcField</code>, or <code>null</code> if not present
     */
    @Nullable Long getSrcField();
    
    /**
     * @return <code>java.lang.Integer</code> <code>srcOfs</code>, or <code>null</code> if not present
     */
    @Nullable Integer getSrcOfs();

}

==> openflowplugin-extension-nicira-0.8.3-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/flow/mod/spec/flow/mod/spec/flow/mod/output/to/port/_case/FlowModOutputToPort.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.flow.mod.output.to.port._case;
import java.lang.Integer;
import java.lang.Long;
import org.eclipse.jdt.annotation.NonNull;
import org.eclipse.jdt.annotation.Nullable;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.FlowModSpec;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.ChildOf;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * container flow-mod-output-to-port {
 *   leaf flow-mod-num-bits {
 *     type uint16;
 *   }
 *   leaf src-field {
 *     type uint32;
 *   }
 *   leaf src-ofs {
 *     type uint16;
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/flow-mod-spec/flow-mod-spec/flow-mod-output-to-port-case/flow-mod-output-to-port</i>
 *
 * <p>To create instances of this class use {@link FlowModOutputToPortBuilder}.
 * @see FlowModOutputToPortBuilder
 *
 */
public interface FlowModOutputToPort
    extends
    ChildOf<FlowModSpec>,
    Augmentable<FlowModOutputToPort>
{



    public static final @NonNull QName QNAME = $YangModuleInfoImpl.qnameOf("flow-mod-output-to-port");

    /**
     * @return <code>java.lang.Integer</code> <code>flowModNumBits</code>, or <code>null</code> if not present
     */
    @Nullable Integer getFlowModNumBits();
    
    /**
     * @return <code>java.lang.Long</code> <code>srcField</code>, or <code>null</code> if not present
     */
    @Nullable Long getSrcField();
    
    /**
     * @return <code>java.lang.Integer</code> <code>srcOfs</code>, or <code>null</code> if not present
     */
    @Nullable Integer getSrcOfs();

}
